@@ -37,7 +37,7 @@
 #' OR
 #'
 #' \itemize{
-#' \item an object of class \code{UPb}, \code{ArAr},
+#' \item an object of class \code{UPb}, \code{PbPb}, \code{ArAr},
 #' \code{RbSr}, \code{SmNd}, \code{ReOs}, \code{LuHf} \code{UThHe} or
 #' \code{fissiontracks}.
 #' }
@@ -156,13 +156,13 @@ age.default <- function(x,method='U238-Pb206',exterr=TRUE,J=c(NA,NA),
 #' \item{cov}{ the covariance matrix of the elements in \code{x} }
 #' }
 #'
-#' \item if \code{x} has class \code{ArAr}, \code{RbSr}, \code{SmNd},
-#' \code{ReOs}, \code{LuHf} and \code{isochron=FALSE}, returns a table of Ar-Ar,
-#' Rb-Sr, Sm-Nd, Re-Os or Lu-Hf ages and standard errors.
+#' \item if \code{x} has class \code{PbPb}, \code{ArAr}, \code{RbSr}, \code{SmNd},
+#' \code{ReOs}, \code{LuHf} and \code{isochron=FALSE}, returns a table of Pb-Pb,
+#' Ar-Ar, Rb-Sr, Sm-Nd, Re-Os or Lu-Hf ages and standard errors.
 #'
-#' \item if \code{x} has class \code{ArAr}, \code{RbSr}, \code{SmNd},
-#' \code{ReOs} or \code{LuHf} and \code{isochron=TRUE}, returns a list with the
-#' following items:
+#' \item if \code{x} has class \code{PbPb}, \code{ArAr}, \code{RbSr},
+#' \code{SmNd}, \code{ReOs} or \code{LuHf} and \code{isochron=TRUE},
+#' returns a list with the following items:
 #'
 #' \describe{
 #'
@@ -172,14 +172,14 @@ age.default <- function(x,method='U238-Pb206',exterr=TRUE,J=c(NA,NA),
 #' \item{b}{ the slope of the fit and its standard error. }
 #' 
 #' \item{y0}{ the atmospheric \eqn{^{40}}Ar/\eqn{^{36}}Ar or initial
-#' \eqn{^{187}}Os/\eqn{^{188}}Os, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
-#' \eqn{^{143}}Nd/\eqn{^{144}}Nd or \eqn{^{176}}Hf/\eqn{^{177}}Hf
-#' ratio and its standard error. }
+#' \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{187}}Os/\eqn{^{188}}Os,
+#' \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd or
+#' \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio and its standard error. }
 #' 
-#' \item{age}{ the \eqn{^{40}}Ar/\eqn{^{39}}Ar,
-#' \eqn{^{187}}Os/\eqn{^{187}}Re, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
-#' \eqn{^{143}}Nd/\eqn{^{144}}Nd or \eqn{^{176}}Hf/\eqn{^{177}}Hf age
-#' and its standard error. }
+#' \item{age}{ the \eqn{^{207}}Pb/\eqn{^{206}}Pb,
+#' \eqn{^{40}}Ar/\eqn{^{39}}Ar, \eqn{^{187}}Os/\eqn{^{187}}Re,
+#' \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd or
+#' \eqn{^{176}}Hf/\eqn{^{177}}Hf age and its standard error. }
 #' 
 #' }
 #' 
@@ -247,22 +247,31 @@ age.UPb <- function(x,type=1,wetherill=TRUE,
         out <- discordia.age(x,wetherill=TRUE,exterr=TRUE,...)
     out
 }
+#' @rdname age
+#' @export
+age.PbPb <- function(x,isochron=TRUE,i2i=TRUE,exterr=TRUE,i=NA,sigdig=NA,...){
+    if (isochron) out <- isochron(x,plot=FALSE,exterr=exterr,sigdig=sigdig,...)
+    else out <- PbPb.age(x,exterr=exterr,i=i,sigdig=sigdig,i2i=i2i,...)
+    out
+}
 #' @param J two-element vector with the J-factor and its standard
 #'     error.
 #' @param isochron logical flag indicating whether each Ar-Ar analysis
 #'     should be considered separately (\code{isochron=FALSE}) or an
 #'     isochron age should be calculated from all Ar-Ar analyses
 #'     together (\code{isochron=TRUE}).
-#' @param i2i
-#'     `isochron to intercept': calculates the initial (aka `inherited',
-#'     `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
+#' @param i2i `isochron to intercept': calculates the initial (aka
+#'     `inherited', `excess', or `common')
+#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
+#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
 #'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
 #'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
-#'     uses the default values stored in \code{settings('iratio',...)}
+#'     uses the default values stored in \code{settings('iratio',...)
+#'     or zero (for the Pb-Pb method).}
 #' @rdname age
 #' @export
 age.ArAr <- function(x,isochron=FALSE,i2i=TRUE,exterr=TRUE,i=NA,sigdig=NA,...){
-    if (isochron) out <- isochron(x,plot=FALSE,...)
+    if (isochron) out <- isochron(x,plot=FALSE,exterr=exterr,sigdig=sigdig,...)
     else out <- ArAr.age(x,exterr=exterr,i=i,sigdig=sigdig,i2i=i2i,...)
     out
 }
@@ -328,6 +337,9 @@ add.exterr <- function(x,tt,st,cutoff.76=1100,type=4){
             R <- age.to.Pb207Pb206.ratio(tt,st)
             out <- get.Pb207Pb206.age(R[,1],R[,2],exterr=TRUE)
         }
+    } else if (hasClass(x,'PbPb')){
+        R <- age.to.Pb207Pb206.ratio(tt,st)
+        out <- get.Pb207Pb206.age(R[,1],R[,2],exterr=TRUE)
     } else if (hasClass(x,'ArAr')){
         R <- get.ArAr.ratio(tt,st,x$J[1],0,exterr=FALSE)
         out <- get.ArAr.age(R[1],R[2],x$J[1],x$J[2],exterr=TRUE)
