@@ -10,8 +10,8 @@
 #' 
 #' @param x a two column matrix of values (first column) and their
 #'     standard errors (second column) OR an object of class
-#'     \code{UPb}, \code{ArAr}, \code{ReOs}, \code{SmNd}, \code{RbSr},
-#'     \code{LuHf}, \code{fissiontracks} or \code{UThHe}
+#'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{ReOs}, \code{SmNd},
+#'     \code{RbSr}, \code{LuHf}, \code{fissiontracks} or \code{UThHe}
 #' @param ... optional arguments
 #' @return if \code{PLOT=FALSE}, returns a list with the following
 #'     items:
@@ -112,13 +112,25 @@ weightedmean.UPb <- function(x,detect.outliers=TRUE,plot=TRUE,
                         cutoff.disc=cutoff.disc,sigdig=sigdig,
                         alpha=alpha,exterr=exterr,...)
 }
-#' @param i2i
-#'     `isochron to intercept': calculates the initial (aka `inherited',
-#'     `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
+#' @param i2i `isochron to intercept': calculates the initial (aka
+#'     `inherited', `excess', or `common')
+#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
 #'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
 #'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
 #'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
-#'     uses the default values stored in \code{settings('iratio',...)}
+#'     uses the default values stored in \code{settings('iratio',...)
+#'     or zero (for the Pb-Pb method).}
+#' @rdname weightedmean
+#' @export
+weightedmean.PbPb <- function(x,detect.outliers=TRUE,plot=TRUE,
+                              rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
+                              alpha=0.05,exterr=TRUE,i2i=FALSE,...){
+    weightedmean.helper(x,detect.outliers=detect.outliers,plot=plot,
+                        rect.col=rect.col,outlier.col=outlier.col,
+                        sigdig=sigdig,alpha=alpha,exterr=exterr,
+                        i2i=i2i,...)
+}
 #' @rdname weightedmean
 #' @export
 weightedmean.ArAr <- function(x,detect.outliers=TRUE,plot=TRUE,
@@ -230,6 +242,8 @@ weightedmean.helper <- function(x,detect.outliers=TRUE,plot=TRUE,
     if (hasClass(x,'UPb')){
         tt <- filter.UPb.ages(x,type=type,cutoff.76=cutoff.76,
                               cutoff.disc=cutoff.disc,exterr=FALSE)
+    } else if (hasClass(x,'PbPb')){
+        tt <- PbPb.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ArAr')){
         tt <- ArAr.age(x,jcu=FALSE,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ReOs')){
